import static org.junit.Assert.*;

import java.io.File;
import java.util.List;

import org.junit.Test;

/** 
 * AsnParser test unit
 * @author foobar@em.boo.jp
 *
 */
public class AsnParserTestCase {
	/**
	 * constractor 
	 * @throws Exception exception
	 */
	public AsnParserTestCase() throws Exception {
		
		//vistor.addInput(new File("snmp/mibs/SNMPv2-SMI"));
		
		File fileList = new File("src/test/config/snmp/mibs");
		fileList = fileList.getAbsoluteFile();
		for (File file : fileList.listFiles()) {
			if (0 <= file.getName().indexOf("orig")) {
				//System.out.println("-- file=" + file.toString() + " is skip");
				continue;
			}
			//System.out.println("-- file=" + file.toString() + " start---");
			try {
				visitor.addInput(file);
			} catch (ParseException e) {
				System.err.println(e.getMessage());
				System.err.println("file  = " + file.getAbsolutePath());
				System.err.println("line  = " + e.currentToken.beginLine);
				throw e;
			} catch(TokenMgrError e) {
				System.err.println(e.getMessage());
				System.err.println("file  = " + file.getAbsolutePath());
				throw e;	
			}
		}
	}

	/**
	 * main test.
	 */
	@Test
	public void testInput() {
		String oid;
		oid = visitor.getOid("iso");
		assertEquals(oid,"1");
		//
		oid = visitor.getOid("org");
		assertEquals(oid,"1.3");
		//
		oid = visitor.getOid("dod");
		assertEquals(oid,"1.3.6");
		//
		oid = visitor.getOid("internet");
		assertEquals(oid,"1.3.6.1");
		//
		oid = visitor.getOid("linkDown");
		assertEquals(oid,"1.3.6.1.6.3.1.1.5.3");
		//
		ASTValueAssignment linkUp = visitor.getNameToValue("linkUp");
		oid = visitor.getOid(linkUp);
		assertEquals(oid,"1.3.6.1.6.3.1.1.5.4");
		//
		List<String> list = visitor.findObjects(linkUp);
		assertEquals(list.get(0),"ifIndex");
		assertEquals(list.get(1),"ifAdminStatus");
		assertEquals(list.get(2),"ifOperStatus");
		//
		//
		ASTValueAssignment ifType = visitor.getNameToValue("ifType");
		oid = visitor.getOid(ifType);
		assertEquals(oid,"1.3.6.1.2.1.2.2.1.3");
		//
		SimpleNode node = visitor.findNode(ifType,AsnParserTreeConstants.JJTSNMPACCESS);
		String accsess = visitor.findString(node);
		assertEquals(accsess,"read-only");
		//
		node = visitor.findNode(linkUp,AsnParserTreeConstants.JJTSNMPDESCRPART);
		String description = visitor.findString(node);
		//System.out.println("descr=" + description);
		assertNotNull(description);
		//
		//
		// RFC1414
		ASTValueAssignment identStatus = visitor.getNameToValue("identStatus");
		SimpleNode syntax = visitor.findNode(identStatus,AsnParserTreeConstants.JJTSNMPSYNTAXPART);
		visitor.dump("",syntax);
	}
	/** visitor */
	private FindOidVisitor visitor = new FindOidVisitor();
}
